@@ -161,7 +161,7 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
     }
   } 
   else if (event->type == GDK_2BUTTON_PRESS) {
-    press_data->status == STATUS_NONE;
+    press_data->status = STATUS_NONE;
     gh_call2 (gh_eval_str ("record-move"), gh_long2scm (-1),
 	      SCM_EOL);
     if (gh_scm2bool (gh_call1 (game_data->button_double_clicked_lambda,
@@ -221,6 +221,7 @@ gint motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
     gdk_window_move(press_data->moving_cards,  
 		    event->x - press_data->xoffset,
 		    event->y - press_data->yoffset);
+    gdk_window_clear(press_data->moving_cards);
   }
   else if (press_data->status == STATUS_MAYBE_DRAG &&
 	   (abs(press_data->xoffset - event->x) > 2 ||
