@@ -29,6 +29,7 @@
 #include <sys/time.h>
 #include <string.h>
 #include <games-clock.h>
+#include <gconf/gconf-client.h>
 
 #include "gataxx.h"
 #include "ataxx.h"
@@ -46,6 +47,8 @@ GtkWidget *black_score;
 GtkWidget *white_score;
 GtkWidget *time_display;
 
+GConfClient *gataxx_gconf_client = NULL;
+
 gint flip_pixmaps_id = 0;
 gint statusbar_id;
 guint whose_turn = BLACK_TURN;
@@ -94,7 +97,7 @@ int session_xpos = -1;
 int session_ypos = -1;
 int session_position = 0;
 
-gchar *tile_set;
+gchar *tile_set = NULL;
 
 guint selected_x;
 guint selected_y;
@@ -121,7 +124,7 @@ GnomeUIInfo game_menu[] = {
 	
 	GNOMEUIINFO_SEPARATOR,
 
-        GNOMEUIINFO_MENU_EXIT_ITEM(quit_game_cb, NULL),
+        GNOMEUIINFO_MENU_QUIT_ITEM(quit_game_cb, NULL),
 
 	GNOMEUIINFO_END
 };
@@ -226,16 +229,22 @@ gboolean quit_game_cb(GtkWidget *widget, gpointer data)
     gint response;
 
     box = gtk_message_dialog_new (GTK_WINDOW (window),
-                                 GTK_DIALOG_DESTROY_WITH_PARENT,
+                                 GTK_DIALOG_MODAL,
                                  GTK_MESSAGE_QUESTION,
-                                 GTK_BUTTONS_YES_NO,
-                                 _("Do you really want to quit?"));
-    gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_YES);
+                                 GTK_BUTTONS_NONE,
+                                 _("Are you sure you want to quit Gataxx?"));
+    gtk_dialog_add_buttons (GTK_DIALOG (box),
+            GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+            GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT,
+            NULL);
+
+    
+    gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_REJECT);
 
     response = gtk_dialog_run (GTK_DIALOG (box));
     gtk_widget_destroy (box);
 
-    if (response == GTK_RESPONSE_NO)
+    if (response == GTK_RESPONSE_REJECT)
       return TRUE;
   }
 
@@ -265,10 +274,11 @@ void new_game_cb(GtkWidget *widget, gpointer data) {
     gint response;
 
     box = gtk_message_dialog_new (GTK_WINDOW (window),
-                                 GTK_DIALOG_DESTROY_WITH_PARENT,
-                                 GTK_MESSAGE_QUESTION,
-                                 GTK_BUTTONS_YES_NO,
-                                 _("Do you really want to end this game?"));
+                     GTK_DIALOG_DESTROY_WITH_PARENT,
+                     GTK_MESSAGE_QUESTION,
+                     GTK_BUTTONS_YES_NO,
+                     _("Are you sure you want to start a new game?"));
+
     gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_YES);
 
     response = gtk_dialog_run (GTK_DIALOG (box));
@@ -352,8 +362,8 @@ void black_level_cb(GtkWidget *widget, gpointer data) {
   
   tmp = atoi((gchar *)data);
   
-  gnome_config_set_int("/gataxx/Preferences/blacklevel", tmp);
-  gnome_config_sync();
+  gconf_client_set_int(gataxx_gconf_client, "/apps/gataxx/blacklevel",
+                       tmp, NULL);
   
   black_computer_level = tmp;
   
@@ -373,8 +383,8 @@ void white_level_cb(GtkWidget *widget, gpointer data)
   
   tmp = atoi((gchar *)data);
   
-  gnome_config_set_int("/gataxx/Preferences/whitelevel", tmp);
-  gnome_config_sync();
+  gconf_client_set_int(gataxx_gconf_client, "/apps/gataxx/whitelevel",
+                       tmp, NULL);
   
   white_computer_level = tmp;
   
@@ -391,7 +401,7 @@ void white_level_cb(GtkWidget *widget, gpointer data)
 void about_cb(GtkWidget *widget, gpointer data) {
 
   static GtkWidget *about;
-  
+  GdkPixbuf *pixbuf = NULL;
   const gchar *authors[] = {"Chris Rogers", NULL};
   gchar *documenters[] = {
                           NULL
@@ -400,17 +410,29 @@ void about_cb(GtkWidget *widget, gpointer data) {
   gchar *translator_credits = _("translator_credits");
   
   if (about != NULL) {
-    gdk_window_raise (about->window);
-    gdk_window_show (about->window);
+    gtk_window_present (GTK_WINDOW(about));
     return;
   }
+
+  {
+	  char *filename = NULL;
+
+	  filename = gnome_program_locate_file (NULL,
+			  GNOME_FILE_DOMAIN_APP_PIXMAP,  ("gataxx.png"),
+			  TRUE, NULL);
+	  if (filename != NULL)
+	  {
+		  pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+		  g_free (filename);
+	  }
+  }
   
   about = gnome_about_new(_("gataxx"), VERSION, "(C) 1999 Chris Rogers",
   			  _("gataxx is a Gnome port of the old game ataxx.  It is derived from Ian Peters' iagno code."),
   			  (const char **)authors,
   			  (const char **)documenters,
   			  strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-			  NULL);
+			  pixbuf);
   g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK
 		      (gtk_widget_destroyed), &about);
   gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW(window));
@@ -538,7 +560,7 @@ void load_pixmaps() {
   GdkPixbuf *image;
   
   tmp = g_strconcat("gataxx/", tile_set, NULL);
-  fname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, (tmp), FALSE, NULL);
+  fname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, (tmp), FALSE, NULL);
   g_free(tmp);
   
   if(!g_file_test (fname, G_FILE_TEST_EXISTS)) {
@@ -627,7 +649,7 @@ gint flip_pixmaps(gpointer data) {
 void init_new_game() {
   
   guint i, j;
-  
+
   if (flip_final_id) {
     gtk_timeout_remove(flip_final_id);
     flip_final_id = 0;
@@ -813,46 +835,45 @@ void set_bg_color() {
   gdk_image_unref(tmpimage);
 }
 
-static char *nstr(int n) {
-
-  char buf[20];
-  sprintf(buf, "%d", n);
-  return strdup(buf);
-}
-
 static int save_state(GnomeClient *client, gint phase, GnomeRestartStyle save_style, gint shutdown, GnomeInteractStyle interact_style, gint fast, gpointer client_data) {
 
   char *argv[20];
   int i;
-  gint xpos, ypos;
+  int xpos, ypos;
   
   gdk_window_get_origin(window->window, &xpos, &ypos);
   
   i = 0;
   argv[i++] = (char *)client_data;
   argv[i++] = "-x";
-  argv[i++] = nstr(xpos);
+  argv[i++] = g_strdup_printf("%d",xpos);
   argv[i++] = "-y";
-  argv[i++] = nstr(ypos);
+  argv[i++] = g_strdup_printf("%d",ypos);
   
   gnome_client_set_restart_command(client, i, argv);
   gnome_client_set_clone_command(client, 0, NULL);
   
-  free(argv[2]);
-  free(argv[4]);
+  g_free(argv[2]);
+  g_free(argv[4]);
   
   return TRUE;
 }
 
-int main(int argc, char **argv) {
+void
+key_changed_cb (GConfClient *tmp_client, guint cnx_id, GConfEntry *tmp_entry,
+                gpointer tmp_data)
+{
+	reload_properties ();
+}
 
-  GnomeClient *client;
+int main(int argc, char **argv) {
+    GnomeClient *client;
 
   /*  CORBA_def(CORBA_Environment ev;) */
     struct timeval tv;
     
     gnome_score_init("gataxx");
-
+  
     bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
@@ -864,7 +885,11 @@ int main(int argc, char **argv) {
     CORBA_exception_init (&ev);
     orb = gnome_CORBA_init_with_popt_table ("gataxx", VERSION, &argc, argv, options, 0, NULL, GNORBA_INIT_SERVER_FUNC|GNORBA_INIT_DISABLE_COOKIES, &ev);
 #else
-    gnome_init_with_popt_table("gataxx", VERSION, argc, argv, options, 0, NULL);
+    gnome_program_init ("gataxx", VERSION,
+       		      LIBGNOMEUI_MODULE, 
+       		      argc, argv,
+       		      GNOME_PARAM_POPT_TABLE, options,
+       		      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 #endif
 
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gataxx.png");
@@ -872,10 +897,17 @@ int main(int argc, char **argv) {
     
     g_signal_connect(G_OBJECT(client), "save_yourself", G_CALLBACK(save_state), argv[0]);
     g_signal_connect(G_OBJECT(client), "die", G_CALLBACK(quit_game_cb), argv[0]);
-  
+
+    gconf_init(argc, argv, NULL);
+    gataxx_gconf_client = gconf_client_get_default();
+    gconf_client_add_dir(gataxx_gconf_client, "/apps/gataxx",
+                         GCONF_CLIENT_PRELOAD_NONE, NULL);
+    gconf_client_notify_add(gataxx_gconf_client, "/apps/gataxx",
+                            key_changed_cb, NULL, NULL, NULL);
+
     create_window();
 
-    load_properties ();
+    load_properties();
     
     load_pixmaps();
     
@@ -893,5 +925,7 @@ int main(int argc, char **argv) {
     
     gtk_main();
     
+    g_object_unref(G_OBJECT(gataxx_gconf_client));
+
     return 0;
 }
