@@ -75,28 +75,6 @@ GnomeUIInfo mainmenu[] = {
 /* Function Definitions                                               */
 /**********************************************************************/
 
-/**
- * really_new_cb
- * @widget: Pointer to widget
- * @data: Callback data
- *
- * Description:
- * Callback to really start new game
- *
- * Returns:
- **/
-static void really_new_cb(
-GtkWidget *widget,
-gpointer  data
-){
-  gint button = GPOINTER_TO_INT(data);
-    
-  if(button != 0) return;
-
-  start_new_game();
-}
-
-
 /**
  * new_cb
  * @widget: Pointer to widget
@@ -113,12 +91,21 @@ gpointer  data
 ){
 
   if(game_state != STATE_NOT_PLAYING){
-    gnome_app_ok_cancel_modal (GNOME_APP(app),
-                               _("Applying this change to Player Selection\nwill end the current game"),
-                               (GnomeReplyCallback)really_new_cb,
-                               NULL);
+    GtkWidget *mb;
+    int response;
+    mb = gtk_message_dialog_new (GTK_WINDOW(app), 
+			   GTK_DIALOG_MODAL,
+			   GTK_MESSAGE_QUESTION,
+			   GTK_BUTTONS_YES_NO,
+			   _("Are you sure you want to start a new game?"),
+			   NULL);
+    response = gtk_dialog_run (GTK_DIALOG(mb));
+    gtk_widget_destroy (mb);
+    if (response == GTK_RESPONSE_YES) {
+      start_new_game();
+    }
   } else {
-    really_new_cb(widget, (gpointer)0);
+    start_new_game();
   }
 }
 
@@ -159,28 +146,6 @@ gpointer  data
 }
 
 
-/**
- * really_exit_cb
- * @widget: Pointer to widget
- * @data: Callback data
- *
- * Description:
- * Callback to really exit game
- *
- * Returns:
- **/
-void really_exit_cb(
-GtkWidget *widget,
-gpointer  data
-){
-  gint button = GPOINTER_TO_INT(data);
-    
-  if(button != 0) return;
-
-  gtk_main_quit();
-}
-
-
 /**
  * exit_cb
  * @widget: Pointer to widget
@@ -191,18 +156,28 @@ gpointer  data
  *
  * Returns:
  **/
-void exit_cb(
-GtkWidget *widget,
-gpointer  data
-){
-
-  if(game_state != STATE_NOT_PLAYING){
-    gnome_app_ok_cancel_modal (GNOME_APP(app),
-                               _("Do you really want to quit the game?"),
-                               (GnomeReplyCallback)really_exit_cb,
-                               NULL);
+void
+exit_cb(GtkWidget *widget, gpointer  data)
+{
+  if(game_state != STATE_NOT_PLAYING) {
+    GtkWidget *mb;
+    int response;
+    mb = gtk_message_dialog_new (GTK_WINDOW(app), 
+				 GTK_DIALOG_MODAL,
+				 GTK_MESSAGE_QUESTION,
+				 GTK_BUTTONS_NONE,
+				 _("Are you sure you want to quit Gnobots II?"),
+				 NULL);
+    gtk_dialog_add_buttons (GTK_DIALOG(mb), GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+			    GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT,
+			    NULL);
+    response = gtk_dialog_run (GTK_DIALOG(mb));
+    gtk_widget_destroy (mb);
+    if (response == GTK_RESPONSE_ACCEPT) {
+      gtk_main_quit();
+    }
   } else {
-    really_exit_cb(widget, (gpointer)0);
+    gtk_main_quit();
   }
 }
 
@@ -221,7 +196,7 @@ static void about_cb(
 GtkWidget *widget, 
 gpointer data
 ){
-  GtkWidget *about = NULL;
+  static GtkWidget *about = NULL;
   GdkPixbuf *pixbuf = NULL;
   
   const gchar *authors[]= {
@@ -234,6 +209,10 @@ gpointer data
   /* Translator credits */
   gchar *translator_credits = _("translator_credits");
 
+  if (about != NULL) {
+    gtk_window_present (GTK_WINDOW(about));
+    return;
+  }
   {
 	  char *filename = NULL;
 
@@ -255,7 +234,8 @@ gpointer data
                           strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
                           pixbuf);
   gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW(app));
-  
+  g_signal_connect (G_OBJECT(about), "destroy", G_CALLBACK(gtk_widget_destroyed), &about);
+
   gtk_widget_show(about);
 }
 
@@ -279,3 +259,36 @@ gboolean create_game_menus(
 }
 
 /**********************************************************************/
+
+/**
+ * update_score_state
+ *
+ * Description:
+ * Changes menu item enabled/disabled state depending on high score availability
+ **/
+void update_score_state ()
+{
+        gchar **names = NULL;
+        gfloat *scores = NULL;
+        time_t *scoretimes = NULL;
+	gint top;
+	gchar sbuf[256];
+
+	  if(properties_super_safe_moves()){
+	    sprintf(sbuf, "%s-super-safe", game_config_filename(current_game_config()));
+	  } else if(properties_safe_moves()){
+	    sprintf(sbuf, "%s-safe", game_config_filename(current_game_config()));
+	  } else {
+	    sprintf(sbuf, "%s", game_config_filename(current_game_config()));
+	  }
+
+	top = gnome_score_get_notable(GAME_NAME, sbuf, &names, &scores, &scoretimes);
+	if (top > 0) {
+		gtk_widget_set_sensitive (gamemenu[2].widget, TRUE);
+		g_strfreev(names);
+		g_free(scores);
+		g_free(scoretimes);
+	} else {
+		gtk_widget_set_sensitive (gamemenu[2].widget, FALSE);
+	}
+}
