@@ -1,6 +1,6 @@
 /* gnome-stones - main.c
  *
- * Time-stamp: <2002/05/02 17:09:45 dave>
+ * Time-stamp: <2002/06/03 16:02:27 ross>
  *
  * Copyright (C) 1998 Carsten Schaar
  *
@@ -104,6 +104,12 @@ static const struct poptOption options[] = {
   {NULL, '\0', 0, NULL, 0}
 };
 
+/****************************************************************************/
+/* The menus */
+static GnomeUIInfo game_menu[];
+static GnomeUIInfo help_menu[];
+static GnomeUIInfo settings_menu[];
+static GnomeUIInfo main_menu[];
 
 
 /****************************************************************************/
@@ -116,6 +122,8 @@ static void
 game_start_cb (GtkWidget *widget, gpointer data);
 
 
+static void
+show_scores_dialog (gint pos);
 
 
 /****************************************************************************/
@@ -134,7 +142,7 @@ load_image_from_path (const char *relative_name)
   gchar         *filename;
   GdkPixbuf *image= NULL;
 
-  filename= gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+  filename= gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
                                        relative_name, TRUE, NULL);
   if (filename)
     image= gdk_pixbuf_new_from_file (filename, NULL);
@@ -466,6 +474,26 @@ game_widget_fill (void)
 }
 #endif /* USE_GNOME_CANVAS */
 
+/****************************************************************************/
+/* High score enabling/disabling */
+
+void update_score_state ()
+{
+        gchar **names = NULL;
+        gfloat *scores = NULL;
+        time_t *scoretimes = NULL;
+	gint top;
+
+	top = gnome_score_get_notable(APP_NAME, NULL, &names, &scores, &scoretimes);
+	if (top > 0) {
+		gtk_widget_set_sensitive (game_menu[5].widget, TRUE);
+		g_strfreev(names);
+		g_free(scores);
+		g_free(scoretimes);
+	} else {
+		gtk_widget_set_sensitive (game_menu[5].widget, FALSE);
+	}
+}
 
 
 /****************************************************************************/
@@ -539,6 +567,7 @@ curtain_ready (ViewCurtainMode mode)
       
       break;
       default:
+      break;
     }
 }
 
@@ -622,9 +651,10 @@ countdown_timeout_function (gpointer data)
 
 	  pos= gnome_score_log (player->score, NULL, TRUE);
 
-	  gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, pos);
-	  gnome_app_flash (GNOME_APP (app), _("Congratulations, you win!"));
+	update_score_state ();
 
+	  gnome_app_flash (GNOME_APP (app), _("Congratulations, you win!"));
+          show_scores_dialog (pos);
 
 	}
       else
@@ -808,11 +838,13 @@ iteration_timeout_function (gpointer data)
 	      /* That's it.  No lives anymore.  */
 	      gint pos= gnome_score_log (player->score, NULL, TRUE);
 
+		update_score_state ();
+
 	      /* FIXME: somewhere is a bug, that makes this needed.  */
 	      if (pos > 10) pos= 0;
 	      
-	      gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, pos);
 	      gnome_app_flash (GNOME_APP (app), _("Game over!"));
+              show_scores_dialog (pos);
 	      curtain_start (NULL);
 	    }
 	}
@@ -916,6 +948,18 @@ load_game (const gchar *filename, guint _start_cave)
 }
 
 
+static void
+show_scores_dialog (gint pos)
+{
+  GtkWidget *dialog;
+
+  dialog = gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, pos);
+  if (dialog != NULL) {
+    gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(app));
+    gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+  }
+}
+
 
 /*****************************************************************************/
 /* Menu callback functions */
@@ -987,14 +1031,14 @@ quit_cb (GtkWidget *widget, gpointer data)
 static void
 show_scores_cb (GtkWidget *widget, gpointer data)
 {
-  gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, GPOINTER_TO_INT (data));
+  show_scores_dialog (GPOINTER_TO_INT (data));
 }
 
 
 static void
 about_cb (GtkWidget *widget, gpointer data)
 {
-  GtkWidget *about= NULL;
+  static GtkWidget *about= NULL;
   GdkPixbuf *pixbuf = NULL;
   
   const gchar *authors[]= {
@@ -1007,11 +1051,15 @@ about_cb (GtkWidget *widget, gpointer data)
   /* Translator credits */
   gchar *translator_credits = _("translator_credits");
 
+  if (about != NULL) {
+    gtk_window_present (GTK_WINDOW(about));
+    return;
+  }
   {
 	  char *filename = NULL;
 
 	  filename = gnome_program_locate_file (NULL,
-			  GNOME_FILE_DOMAIN_PIXMAP,  ("gnome-stones.png"),
+			  GNOME_FILE_DOMAIN_APP_PIXMAP,  ("gnome-stones.png"),
 			  TRUE, NULL);
 	  if (filename != NULL)
 	  {
@@ -1026,6 +1074,8 @@ about_cb (GtkWidget *widget, gpointer data)
                           (const char **)documenters,
                           strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			  pixbuf);
+  gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (app));
+  g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
   gtk_widget_show (about);
 }
 
@@ -1096,7 +1146,7 @@ scan_private_game_directory (void)
 static gboolean
 scan_public_plugin_directory (void)
 {
-  char *dir= gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_LIBDIR, 
+  char *dir= gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_LIBDIR, 
                                         "gnome-stones/objects/", FALSE, NULL);
 
   plugin_load_plugins_in_dir (dir);
@@ -1226,14 +1276,15 @@ main (int argc, char *argv[])
       		      LIBGNOMEUI_MODULE, 
        		      argc, argv,
        		      GNOME_PARAM_POPT_TABLE, options,
-       		      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+       		      GNOME_PARAM_APP_DATADIR, DATADIR,
+		      GNOME_PARAM_APP_LIBDIR, LIBDIR, NULL);
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-stones.png");
   /* That's what a gnome application needs:  */
   app= gnome_app_new ("gnome-stones", _("Gnome-Stones"));
   gtk_window_set_policy  (GTK_WINDOW (app), FALSE, FALSE, TRUE);
 
   /* ... a menu line, ... */
-  gnome_app_create_menus   (GNOME_APP (app), main_menu);
+  gnome_app_create_menus (GNOME_APP (app), main_menu);
 
   /* ... a toolbar, ... */
   /*  gnome_app_create_toolbar (GNOME_APP (app), toolbar); */
@@ -1266,6 +1317,10 @@ main (int argc, char *argv[])
   
   gtk_widget_set_events (app, gtk_widget_get_events (app) | GAME_EVENTS);
 
+ /* are there any high scores? */
+
+  update_score_state ();
+
   g_signal_connect (GTK_OBJECT (app), "key_press_event",
 		      GTK_SIGNAL_FUNC (game_widget_key_press_callback), 0);
   g_signal_connect (GTK_OBJECT (app), "key_release_event",
