@@ -96,9 +96,11 @@ int valid_drop(int,int);
 void move_column(unsigned char);
 int game_over();
 void game_score();
+void update_score_state ();
 gint timer_cb();
 void timer_start();
 void pause_cb();
+void gui_draw_pause();
 static int save_state(GnomeClient*, gint, GnomeRestartStyle, gint, GnomeInteractStyle, gint, gpointer);
 
 
@@ -231,6 +233,8 @@ int main (int argc, char **argv){
   create_space(); 
   create_statusbar();
 
+  update_score_state ();
+
   if(session_xpos >= 0 && session_ypos >= 0)
     gtk_widget_set_uposition(window, session_xpos, session_ypos);
     
@@ -524,10 +528,21 @@ int game_over(){
   return 1;
 }
 
+void show_score_dialog(const gchar *level, gint pos)
+{
+  GtkWidget *dialog;
+
+  dialog = gnome_scores_display (_(APPNAME_LONG), APPNAME, level, pos);
+  if (dialog != NULL) {
+    gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(window));
+    gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+  }
+}
+
 void score_cb(GtkWidget *widget, gpointer data){
   gchar level[5];
   sprintf(level,"%dx%d",SIZE,SIZE);
-  gnome_scores_display (_(APPNAME_LONG), APPNAME, level, 0);
+  show_score_dialog (level, 0);
 }
 
 void game_score(){
@@ -541,7 +556,29 @@ void game_score(){
   games_clock_set_seconds(GAMES_CLOCK(timer), (int) seconds);
   score = (gfloat) (seconds / 60) + (gfloat) (seconds % 60) / 100;
   pos = gnome_score_log(score,level,FALSE);
-  gnome_scores_display (_(APPNAME_LONG), APPNAME, level, pos);
+  update_score_state ();
+  show_score_dialog (level, pos);
+}
+
+void update_score_state ()
+{
+        gchar **names = NULL;
+        gfloat *scores = NULL;
+        time_t *scoretimes = NULL;
+	gint top;
+	gchar level[5];
+
+	sprintf(level,"%dx%d",SIZE,SIZE);
+
+	top = gnome_score_get_notable(APPNAME, level, &names, &scores, &scoretimes);
+	if (top > 0) {
+		gtk_widget_set_sensitive (game_menu[6].widget, TRUE);
+		g_strfreev(names);
+		g_free(scores);
+		g_free(scoretimes);
+	} else {
+		gtk_widget_set_sensitive (game_menu[6].widget, FALSE);
+	}
 }
 
 gint configure_space(GtkWidget *widget, GdkEventConfigure *event){
@@ -572,13 +609,17 @@ void redraw_all(){
     gdk_gc_unref(draw_gc);
 
   gdk_window_end_paint(space->window);
+  gdk_region_destroy(region);
 }
 
 void redraw_left(){
   int x,y;
   GdkRegion *region;
+  GdkRectangle rect ={x:CORNER, y:CORNER, width:TILE_SIZE*SIZE,
+		     height:TILE_SIZE*SIZE};
+
+  region = gdk_region_rectangle(&rect);
 
-  region = gdk_drawable_get_clip_region(GDK_DRAWABLE(space->window));
   gdk_window_begin_paint_region(space->window, region); 
 
   for(y = 0; y < SIZE; y++)
@@ -586,6 +627,7 @@ void redraw_left(){
       gui_draw_pixmap(buffer, x, y);
 
   gdk_window_end_paint(space->window);
+  gdk_region_destroy(region);
 }
 
 void create_space(){
@@ -749,13 +791,89 @@ void pause_cb(){
   paused = !paused;
   if(paused){
     message(_("... Game paused ..."));
+    gui_draw_pause();
     games_clock_stop(GAMES_CLOCK(timer));
   } else {
     message("");
+    redraw_all();
     games_clock_start(GAMES_CLOCK(timer));
   }
 }
 
+void gui_draw_pause(){
+  guint x, y, xadd, yadd, which;
+  GdkRegion *region;
+  GdkGC *gc;
+
+  region = gdk_drawable_get_clip_region(GDK_DRAWABLE(space->window));
+  gdk_window_begin_paint_region(space->window, region);
+
+  for(y = 0; y < SIZE; y++) {
+    for(x = 0; x < SIZE*2; x++) {
+      which = tiles[y][x].status;
+
+      xadd = x * TILE_SIZE + CORNER + (x >= SIZE)*GAP;
+      yadd = y * TILE_SIZE + CORNER;
+      gc = space->style->black_gc;
+
+      gdk_draw_drawable(buffer, gc, tiles_pixmap,
+                      which * TILE_SIZE, 0, 
+                      xadd, yadd, TILE_SIZE, TILE_SIZE);
+
+      if(which == USED) {
+        /* North */
+        gdk_draw_drawable(buffer,
+                        gc,
+                        tiles_pixmap,
+                        0,
+                        TILE_SIZE+1, 
+                        xadd + TILE_SIZE/2-3,
+                        yadd + 5,
+                        9,
+                        13);
+
+        /* South */
+        gdk_draw_drawable(buffer,
+                        gc,
+                        tiles_pixmap,
+                        0,
+                        TILE_SIZE+1, 
+                        xadd + TILE_SIZE/2-3,
+                        yadd + TILE_SIZE-17,
+                        9,
+                        13);
+
+        /* West */
+	gdk_draw_drawable(buffer,
+                        gc,
+                        tiles_pixmap,
+                        0,
+                        TILE_SIZE+1, 
+                        xadd + 5,
+                        yadd + TILE_SIZE/2-6,
+                        9,
+                        13);
+ 
+        /* East */
+        gdk_draw_drawable(buffer,
+                        gc,
+                        tiles_pixmap,
+                        0,
+                        TILE_SIZE+1, 
+                        xadd + TILE_SIZE-13,
+                        yadd + TILE_SIZE/2-6,
+                        9,
+                        13);
+        }
+
+        gtk_widget_queue_draw_area (space, xadd, yadd, TILE_SIZE, TILE_SIZE);
+     }
+  }
+
+  gdk_window_end_paint(space->window);
+  gdk_region_destroy(region);
+}
+
 void timer_start(){
   games_clock_stop(GAMES_CLOCK(timer));
   games_clock_set_seconds(GAMES_CLOCK(timer), 0);
@@ -834,6 +952,7 @@ void size_cb(GtkWidget *widget, gpointer data){
   int size;
   size = atoi((gchar *)data);
   SIZE = size;
+  update_score_state ();
   new_game_cb(space,NULL);
 }
 
@@ -962,7 +1081,7 @@ void solve_cb(GtkWidget *widget, gpointer data){
 }
 
 void about_cb(GtkWidget *widget, gpointer data){
-  GtkWidget *about;
+  static GtkWidget *about = NULL;
   GdkPixbuf *pixbuf = NULL;
   
   const gchar *authors[] = { "Lars Rydlinge", NULL };
@@ -972,6 +1091,10 @@ void about_cb(GtkWidget *widget, gpointer data){
   /* Translator credits */
   gchar *translator_credits = _("translator_credits");
 
+  if (about != NULL) {
+    gtk_window_present (GTK_WINDOW(about));
+    return;
+  }
   {
 	  char *filename = NULL;
 
@@ -995,6 +1118,7 @@ void about_cb(GtkWidget *widget, gpointer data){
                           strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			  pixbuf);
   gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
+  g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
   gtk_widget_show(about);
 }
 
