@@ -256,6 +256,7 @@ static GdkPixbuf *tiles_image, *bg_image;
 static gchar *tileset = NULL;
 static gchar *bg_tileset = NULL;
 static gchar *mapset = NULL;
+static gchar *score_current_mapset = NULL;
 
 static gchar *selected_tileset = NULL;
 static gchar *selected_bg = NULL;
@@ -434,6 +435,7 @@ GnomeUIInfo toolbar_uiinfo [] = {
 };
 
 #define PAUSE_BUTTON GTK_TOGGLE_BUTTON(toolbar_uiinfo[6].widget)
+#define HIGHSCORE_WIDGET gamemenu[9].widget
 
 static void
 tileset_callback (GtkWidget *widget, void *data)
@@ -663,7 +665,7 @@ mapset_changed_cb (GConfClient *client,
 		g_free (mapset_tmp);
 	
 	dialog = gtk_message_dialog_new (
-		NULL,
+		GTK_WINDOW (window),
 		GTK_DIALOG_MODAL,
 		GTK_MESSAGE_INFO,
 		GTK_BUTTONS_CLOSE,
@@ -736,6 +738,25 @@ message (gchar *message)
 	gnome_appbar_push (GNOME_APPBAR (appbar), message);
 }
 
+void update_score_state ()
+{
+        gchar **names = NULL;
+        gfloat *scores = NULL;
+        time_t *scoretimes = NULL;
+	gint top;
+
+	top = gnome_score_get_notable(APPNAME, score_current_mapset, &names, &scores, &scoretimes);
+	if (top > 0) {
+		gtk_widget_set_sensitive (HIGHSCORE_WIDGET, TRUE);
+		g_strfreev(names);
+		g_free(scores);
+		g_free(scoretimes);
+	} else {
+		gtk_widget_set_sensitive (HIGHSCORE_WIDGET, FALSE);
+	}
+}
+
+
 void
 chrono_start (void)
 {
@@ -1054,8 +1075,8 @@ you_won (void)
         seconds = GAMES_CLOCK (chrono)->stopped;
 
         score = (seconds / 60) * 1.0 + (seconds % 60) / 100.0;
-        if (!(pos = gnome_score_log (score, mapset, FALSE))) {
-                gnome_scores_display (_(APPNAME_LONG), APPNAME, mapset, pos);
+        if (pos = gnome_score_log (score, score_current_mapset, FALSE)) {
+                gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, pos);
                 message = g_strdup_printf
 			(_("Fantastic!  %.2f!\n"
 			   "You have reached #%d in the Top Ten.\n\n"
@@ -1065,6 +1086,8 @@ you_won (void)
 			(_("Great!\nYou made it in %.2f.\n\n"
 			   "Another game?"), score);
 	}
+
+	update_score_state ();
        	
        	dialog = gtk_message_dialog_new (
 		GTK_WINDOW (window),
@@ -1411,7 +1434,7 @@ void ensure_pause_off (void)
 void
 scores_callback (GtkWidget *widget, gpointer data)
 {
-        gnome_scores_display (_(APPNAME_LONG), APPNAME, mapset, 0);
+        gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, 0);
 }
 
 void
@@ -1440,26 +1463,45 @@ confirm_action (GtkWidget *widget, gpointer data)
 		
 		switch ((game_state)data) {
 		case RESTART_GAME :
-			confirm_text = _("Really restart this game?");
+			confirm_text = _("Are you sure you want to restart this game?");
 			break;
 		case QUIT_GAME :
 			/* GNOME IS AN ACRONYM, DAMNIT! */
-			confirm_text = _("Really exit GNOME Mahjongg?");
+			confirm_text = _("Are you sure you want to quit GNOME Mahjongg?");
 			break;
 		case NEW_GAME:
 		case NEW_GAME_WITH_SEED:
-			confirm_text = _("Really start a new game?");
+			confirm_text = _("Are you sure you want to start a new game?");
 			break;
 		default:
 			confirm_text = _("Serious internal error");
 			break;
 		}
-			
-		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+
+		/* Special case the quit because the buttons are different */
+
+		if ((game_state)data == QUIT_GAME)
+		{
+			dialog = gtk_message_dialog_new (GTK_WINDOW (window),
 						 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_QUESTION,
-						 GTK_BUTTONS_YES_NO,
+						 GTK_BUTTONS_NONE,
 						 confirm_text);
+			gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+						GTK_STOCK_CANCEL,
+						GTK_RESPONSE_NO,
+						GTK_STOCK_QUIT,
+						GTK_RESPONSE_YES,
+						NULL);
+		}
+		else {
+                        dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                                                 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                 GTK_MESSAGE_QUESTION,
+                                                 GTK_BUTTONS_YES_NO,
+                                                 confirm_text);
+		}
+
 		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
 
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1868,6 +1910,7 @@ create_mahjongg_board (GtkWidget *mbox)
         g_free (buf2);
 	g_free (buf);
 	init_game ();
+	update_score_state ();
 }
 
 void
@@ -1895,6 +1938,12 @@ new_game (gboolean re_seed)
 	}
 
 	init_game ();
+
+	if (score_current_mapset != NULL)
+		g_free (score_current_mapset);
+
+	score_current_mapset = strdup (mapset);
+	update_score_state ();
 }
 
 void
@@ -1908,7 +1957,7 @@ shuffle_tiles_callback (GtkWidget *widget, gpointer data)
 
         do {
                 num_shuffle++;
-                /* We do a circular permutation (FIXME: check the english term...)*/
+                /* We do a circular permutation */
                 for (i=0; i<MAX_TILES; i++) {
                         if (tiles[i].visible) {
                                 if (first) {
@@ -1936,6 +1985,7 @@ shuffle_tiles_callback (GtkWidget *widget, gpointer data)
 					     GTK_BUTTONS_OK,
 					     (_("Sorry, I was unable to find a playable configuration.")));
 		gtk_dialog_run (GTK_DIALOG (mb));
+		gtk_widget_destroy (mb);
 
         } else {
                 
@@ -1957,6 +2007,41 @@ shuffle_tiles_callback (GtkWidget *widget, gpointer data)
         }
 }
 
+static void 
+gconf_sanity_check(void)
+{
+  gchar *tileset;
+  GError *error = NULL;
+  
+  tileset = gconf_client_get_string (conf_client,
+                                     "/apps/mahjongg/tileset", &error);
+  if (error) {
+    GtkWidget *dialog;
+    dialog = gtk_message_dialog_new (NULL,
+                                     0,
+                                     GTK_MESSAGE_ERROR,
+                                     GTK_BUTTONS_CLOSE,
+                                     _("There was an error accessing GConf: %s"),
+                                     error->message);
+    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+    gtk_dialog_run(GTK_DIALOG(dialog));
+    exit(1);
+  } else if (!tileset) {
+    GtkWidget *dialog;
+    dialog = gtk_message_dialog_new (NULL,
+                                     0,
+                                     GTK_MESSAGE_ERROR,
+                                     GTK_BUTTONS_CLOSE,
+                                     _("The default configuration values could not be retrieved correctly. Please check your GConf configuration, specifically that the schemas are installed correctly"));
+    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+    gtk_dialog_run(GTK_DIALOG(dialog));
+    exit(1);
+  } else {
+    g_message(tileset);
+    g_free (tileset);
+  }
+}
+
 int
 main (int argc, char *argv [])
 {
@@ -1981,6 +2066,7 @@ main (int argc, char *argv [])
         gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-mahjongg.png");
 	new_seed ();
 	conf_client = gconf_client_get_default ();
+	gconf_sanity_check();
 
 	window = gnome_app_new (APPNAME, _(APPNAME_LONG));
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
@@ -2056,6 +2142,8 @@ main (int argc, char *argv [])
 
 	init_config();
 
+	update_score_state ();
+
   	gnome_app_flash (GNOME_APP (window), 
   				_("Welcome to GNOME Mahjongg!")); 
 
